aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristophe Lyon <christophe.lyon@linaro.org>2023-11-30 09:15:20 +0000
committerChristophe Lyon <christophe.lyon@linaro.org>2023-11-30 09:16:55 +0000
commit40183f5707775485a2767c754bc44087450ad937 (patch)
treefd93bda6fc4fb8a23bc96fe1af59195c6d22adb4
parentd28e5dd8c4cb36ba014aef7c3cb9c6968d2c8f72 (diff)
scripts/testresults2jenkins.sh: Rename output file with recipients
from mail-recipient.txt to mail-recipients.txt for consistency with our other scripts. Change-Id: I44f509cdb350183065ad2c7923da817c7274abcb
-rwxr-xr-xscripts/testresults2jenkins.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/scripts/testresults2jenkins.sh b/scripts/testresults2jenkins.sh
index aaf36f61..cbd6d2af 100755
--- a/scripts/testresults2jenkins.sh
+++ b/scripts/testresults2jenkins.sh
@@ -2,15 +2,15 @@
# This script transforms the output of GCC's contrib/test_summary (an
# email) into a format suitable for consumption by our Jenkins CI:
# three files, containing subject, recipient and body.
#
# In order to be used transparently as a replacement for "Mail",
# it uses the same interface as the "Mail" command:
#
-# cat body | testresults2jenkins.sh -s "subject" "recipient"
+# cat body | testresults2jenkins.sh -s "subject" "recipients"
#
# its output goes intro three files:
-# - testresults-mail-recipient.txt
+# - testresults-mail-recipients.txt
# - testresults-mail-subject.txt
# - testresults-mail-body.txt
#
@@ -19,7 +19,7 @@
usage()
{
- echo "Usage: $0 -s subject recipient"
+ echo "Usage: $0 -s subject recipients"
exit 1
}
@@ -32,10 +32,10 @@ if [ "$1" != "-s" ]; then
fi
subject="$2"
-recipient="$3"
+recipients="$3"
TESTRESULTS_PREFIX=${TESTRESULTS_PREFIX-$(pwd)/testresults-}
-echo "to:$recipient" > ${TESTRESULTS_PREFIX}mail-recipient.txt
+echo "to:$recipients" > ${TESTRESULTS_PREFIX}mail-recipients.txt
echo "$subject" > ${TESTRESULTS_PREFIX}mail-subject.txt
cat > ${TESTRESULTS_PREFIX}mail-body.txt
@@ -2,15 +2,15 @@
# This script transforms the output of GCC's contrib/test_summary (an
# email) into a format suitable for consumption by our Jenkins CI:
-# three files, containing subject, recipient and body.
+# three files, containing subject, recipients and body.
#
# In order to be used transparently as a replacement for "Mail",